@@ -1,6 +1,7 @@
 /*
     This file is from KOrganizer.
     Copyright (c) 2002 Cornelius Schumacher <schumacher@kde.org>
+    Copyright (c) 2004-2005 Anne-Marie Mahfouf <annma@kde.org> 
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +15,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
     As a special exception, permission is given to link this program
     with any edition of Qt, and distribute the resulting executable,
@@ -28,6 +29,7 @@
 #include <qdir.h>
 #include <kaction.h>
 
+#include "prefs.h"
 #include "khnewstuff.h"
 
 KHNewStuff::KHNewStuff( KHangManView *view ) :
@@ -38,22 +40,28 @@ KHNewStuff::KHNewStuff( KHangManView *view ) :
 
 bool KHNewStuff::install( const QString &fileName )
 {
-	kdDebug(5850) << "KHNewStuff::install(): " << fileName << endl;
-	
-	KTar archive( fileName );
-	if ( !archive.open( IO_ReadOnly ) )
-			return false;
-	const KArchiveDirectory *archiveDir = archive.directory();
-	KStandardDirs myStdDir;
-	const QString destDir =myStdDir.saveLocation("data", kapp->instanceName() + "/data/", true);      
-	KStandardDirs::makeDir( destDir );
-	archiveDir->copyTo(destDir);
-	archive.close();
-	return true;
+    kdDebug(5850) << "KHNewStuff::install(): " << fileName << endl;
+    
+    KTar archive( fileName );
+    if ( !archive.open( IO_ReadOnly ) )
+                    return false;
+    const KArchiveDirectory *archiveDir = archive.directory();
+    KStandardDirs myStdDir;
+    const QString destDir =myStdDir.saveLocation("data", kapp->instanceName() + "/data/", true);      
+    KStandardDirs::makeDir( destDir );
+    archiveDir->copyTo(destDir);
+    archive.close();
+        //look for languages dirs installed
+    m_view->khangman->setLanguages();
+    //refresh Languages menu
+    m_view->khangman->m_languageAction->setItems(m_view->khangman->m_languageNames);
+    m_view->khangman->slotChangeLanguage(m_view->khangman->m_languages.findIndex(Prefs::selectedLanguage()));
+    m_view->khangman->m_languageAction->setCurrentItem(m_view->khangman->m_languages.findIndex(Prefs::selectedLanguage()));
+    return true;
 }
 
-bool KHNewStuff::createUploadFile( const QString &fileName )
+bool KHNewStuff::createUploadFile( const QString &/*fileName*/ )
 {
-  	//return mView->saveCalendar( fileName );
- 	 return true;
+    //return mView->saveCalendar( fileName );
+    return true;
 }
