@@ -49,10 +49,11 @@
 #include "ksasteroid.h"
 #include "kscomet.h"
 #include "starobject.h"
+#include "customcatalog.h"
 
 SkyMap::SkyMap(KStarsData *d, QWidget *parent, const char *name )
- : QWidget (parent,name), computeSkymap(true), 
-		ksw(0), data(d), pmenu(0), sky(0), IBoxes(0), 
+	: QWidget (parent,name), computeSkymap(true), angularDistanceMode(false),
+		ksw(0), data(d), pmenu(0), sky(0), sky2(0), IBoxes(0), 
 		ClickedObject(0), FocusObject(0), TransientObject(0),
 		starpix(0), pts(0), sp(0)
 {
@@ -85,6 +86,7 @@ SkyMap::SkyMap(KStarsData *d, QWidget *parent, const char *name )
 	FocusObject = NULL;
 
 	sky = new QPixmap();
+	sky2 = new QPixmap();
 	pmenu = new KSPopupMenu( ksw );
 	
 	//Initialize Transient label stuff
@@ -133,6 +135,7 @@ SkyMap::~SkyMap() {
 	delete pts;
 	delete sp;
 	delete sky;
+	delete sky2;
 	delete pmenu;
 	delete IBoxes;
 
@@ -155,27 +158,32 @@ SkyMap::~SkyMap() {
 void SkyMap::setGeometry( int x, int y, int w, int h ) {
 	QWidget::setGeometry( x, y, w, h );
 	sky->resize( w, h );
+	sky2->resize( w, h );
 }
 
 void SkyMap::setGeometry( const QRect &r ) {
 	QWidget::setGeometry( r );
 	sky->resize( r.width(), r.height() );
+	sky2->resize( r.width(), r.height() );
 }
 
 
-void SkyMap::showFocusCoords( void ) {
-	//display object info in infoBoxes
-	QString oname;
-	oname = i18n( "nothing" );
-	if ( focusObject() != NULL && Options::isTracking() ) 
-		oname = focusObject()->translatedLongName();
-	
-	infoBoxes()->focusObjChanged(oname);
+void SkyMap::showFocusCoords( bool coordsOnly ) {
+	if ( ! coordsOnly ) {
+		//display object info in infoBoxes
+		QString oname;
+		oname = i18n( "nothing" );
+		if ( focusObject() != NULL && Options::isTracking() ) 
+			oname = focusObject()->translatedLongName();
+		
+		infoBoxes()->focusObjChanged(oname);
+	}
 
 	if ( Options::useAltAz() && Options::useRefraction() ) {
 		SkyPoint corrFocus( *(focus()) );
 		corrFocus.setAlt( refract( focus()->alt(), false ) );
 		corrFocus.HorizontalToEquatorial( data->LST, data->geo()->lat() );
+		corrFocus.setAlt( refract( focus()->alt(), true ) );
 		infoBoxes()->focusCoordChanged( &corrFocus );
 	} else {
 		infoBoxes()->focusCoordChanged( focus() );
@@ -315,13 +323,13 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 	int icust_min = -1;
 	int icust_cat = -1;
 
-	for ( register unsigned int j=0; j<Options::catalogCount(); ++j ) {
+	for ( register unsigned int j=0; j< data->CustomCatalogs.count(); ++j ) {
 		if ( Options::showCatalog()[j] ) {
-			QPtrList<DeepSkyObject> cat = data->CustomCatalogs[ Options::catalogName()[j] ];
+			QPtrList<SkyObject> catList = data->CustomCatalogs.at(j)->objList();
 
-			for ( register unsigned int i=0; i<cat.count(); ++i ) {
+			for ( register unsigned int i=0; i<catList.count(); ++i ) {
 				//test RA and dec to see if this object is roughly nearby
-				SkyObject *test = (SkyObject *)cat.at(i);
+				SkyObject *test = (SkyObject *)catList.at(i);
 				double dRA = test->ra()->Hours()-p->ra()->Hours();
 				double dDec = test->dec()->Degrees()-p->dec()->Degrees();
 				double f = 15.0*cos( test->dec()->radians() );
@@ -385,7 +393,7 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 		icat = 3; //set catalog to solar system
 	}
 
-	QPtrList<DeepSkyObject> cat;
+	QPtrList<SkyObject> cat;
 
 	switch (icat) {
 		case 0: //star
@@ -397,7 +405,7 @@ SkyObject* SkyMap::objectNearest( SkyPoint *p ) {
 			break;
 
 		case 2: //Custom Catalog Object
-			cat = data->CustomCatalogs[ Options::catalogName()[icust_cat] ];
+			cat = data->CustomCatalogs.at(icust_cat)->objList();
 			return cat.at(icust_min);
 			break;
 
@@ -423,12 +431,12 @@ void SkyMap::slotTransientLabel( void ) {
 	//TransientLabel and then set TransientObject to NULL.
 	//
 	//Do not show a transient label if the map is in motion, or if the mouse 
-	//pointer is below the opaque horizon
+	//pointer is below the opaque horizon, or if the object has a permanent label
 	if ( ! slewing && ! ( Options::useAltAz() && Options::showGround() && 
 			mousePoint()->alt()->Degrees() < 0.0 ) ) {
 		SkyObject *so = objectNearest( mousePoint() );
 		
-		if ( so ) {
+		if ( so && ! isObjectLabeled( so ) ) {
 			setTransientObject( so );
 			
 			TransientColor = data->colorScheme()->colorNamed( "UserLabelColor" );
@@ -442,6 +450,13 @@ void SkyMap::slotTransientLabel( void ) {
 //Slots
 
 void SkyMap::slotTransientTimeout( void ) {
+	//Don't fade label if the transientObject is now the focusObject!
+	if ( transientObject() == focusObject() && Options::useAutoLabel() ) {
+		setTransientObject( NULL );
+		TransientTimer.stop();
+		return;
+	}
+
 	//to fade the labels, we will need to smoothly transition from UserLabelColor to SkyColor.
 	QColor c1 = data->colorScheme()->colorNamed( "UserLabelColor" );
 	QColor c2 = data->colorScheme()->colorNamed( "SkyColor" );
@@ -493,7 +508,7 @@ void SkyMap::slotCenter( void ) {
 		QString caption = i18n( "Requested Position Below Horizon" );
 		QString message = i18n( "The requested position is below the horizon.\nWould you like to go there anyway?" );
 		if ( KMessageBox::warningYesNo( this, message, caption,
-				KStdGuiItem::yes(), KStdGuiItem::no(), "dag_focus_below_horiz" )==KMessageBox::No ) {
+				i18n("Go Anyway"), i18n("Keep Position"), "dag_focus_below_horiz" )==KMessageBox::No ) {
 			setClickedObject( NULL );
 			setFocusObject( NULL );
 			Options::setIsTracking( false );
@@ -522,14 +537,23 @@ void SkyMap::slotCenter( void ) {
 
 	//update the destination to the selected coordinates
 	if ( Options::useAltAz() ) { 
-		setDestinationAltAz( focusPoint()->alt()->Degrees(), focusPoint()->az()->Degrees() );
+		if ( Options::useRefraction() )
+			setDestinationAltAz( refract( focusPoint()->alt(), true ).Degrees(), focusPoint()->az()->Degrees() );
+		else
+			setDestinationAltAz( focusPoint()->alt()->Degrees(), focusPoint()->az()->Degrees() );
 	} else {
 		setDestination( focusPoint() );
 	}
 
+	focusPoint()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
+
 	//display coordinates in statusBar
 	if ( ksw ) {
-		QString s = focusPoint()->az()->toDMSString() + ",  " + focusPoint()->alt()->toDMSString(true);
+		QString sX = focusPoint()->az()->toDMSString();
+		QString sY = focusPoint()->alt()->toDMSString(true);
+		if ( Options::useAltAz() && Options::useRefraction() )
+			sY = refract( focusPoint()->alt(), true ).toDMSString(true);
+		QString s = sX + ",  " + sY;
 		ksw->statusBar()->changeItem( s, 1 );
 		s = focusPoint()->ra()->toHMSString() + ",  " + focusPoint()->dec()->toDMSString(true);
 		ksw->statusBar()->changeItem( s, 2 );
@@ -690,6 +714,8 @@ void SkyMap::slotRemoveObjectLabel( void ) {
 
 void SkyMap::slotAddObjectLabel( void ) {
 	data->ObjLabelList.append( clickedObject() );
+	//Since we just added a permanent label, we don't want it to fade away!
+	if ( transientObject() == clickedObject() ) setTransientObject( NULL );
 	forceUpdate();
 }
 
@@ -810,9 +836,10 @@ void SkyMap::updateFocus() {
 	if ( Options::isTracking() && focusObject() != NULL ) {
 		if ( Options::useAltAz() ) {
 			//Tracking any object in Alt/Az mode requires focus updates
-			setFocusAltAz(
-					refract( focusObject()->alt(), true ).Degrees(),
-					focusObject()->az()->Degrees() );
+			double dAlt = focusObject()->alt()->Degrees();
+			if ( Options::useRefraction() ) 
+				dAlt = refract( focusObject()->alt(), true ).Degrees();
+			setFocusAltAz( dAlt, focusObject()->az()->Degrees() );
 			focus()->HorizontalToEquatorial( data->LST, data->geo()->lat() );
 			setDestination( focus() );
 		} else {
@@ -843,6 +870,9 @@ void SkyMap::updateFocus() {
 		}
 	}
 
+	//Update the Hour Angle
+	data->setHourAngle( data->LST->Hours() - focus()->ra()->Hours() );
+
 	setOldFocus( focus() );
 	oldfocus()->EquatorialToHorizontal( data->LST, data->geo()->lat() );
 }
@@ -933,7 +963,8 @@ void SkyMap::slewFocus( void ) {
 
 		//Start the HoverTimer. if the user leaves the mouse in place after a slew,
 		//we want to attach a label to the nearest object.
-		HoverTimer.start( HOVER_INTERVAL, true );
+		if ( Options::useHoverLabel() )
+			HoverTimer.start( HOVER_INTERVAL, true );
 		
 		forceUpdate();
 	}
@@ -967,10 +998,6 @@ double SkyMap::findPA( SkyObject *o, int x, int y, double scale ) {
 		if ( dx > 0 ) north = -90.0;
 	}
 
-	//DEBUG
-	if ( o->name() == "M 31" ) 
-	  qDebug( "M 31: dx: %f  dy: %f  north: %f   o->pa(): %f", dx, dy, north, o->pa() );
-
 	return ( north + o->pa() );
 }
 
@@ -1008,7 +1035,7 @@ QPoint SkyMap::getXY( SkyPoint *o, bool Horiz, bool doRefraction, double scale )
   }
 
 	//Convert dX, Y coords to screen pixel coords.
-	#if ( __GLIBC__ >= 2 && __GLIBC_MINOR__ >=1 )
+	#if ( __GLIBC__ >= 2 && __GLIBC_MINOR__ >=1 ) && !defined(__UCLIBC__)
 	//GNU version
 	sincos( dX, &sindX, &cosdX );
 	sincos( Y, &sinY, &cosY );
@@ -1143,7 +1170,7 @@ void SkyMap::forceUpdate( bool now )
 
 	if (! unusablePoint (dx, dy)) {
 		//determine RA, Dec of mouse pointer
-		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat() ) );
+		setMousePoint( dXdYToRaDec( dx, dy, Options::useAltAz(), data->LST, data->geo()->lat(), Options::useRefraction() ) );
 	}
 
 	computeSkymap = true;
@@ -1160,13 +1187,17 @@ float SkyMap::fov() {
 
 bool SkyMap::checkVisibility( SkyPoint *p, float FOV, double XMax ) {
 	double dX, dY;
-
-//Skip objects below the horizon if the ground is drawn.
-//commented out because ground disappears if it fills the view
-//	if ( useAltAz && drawGround && p->alt()->Degrees() < -2.0 ) return false;
-
 	bool useAltAz = Options::useAltAz();
 
+	//Skip objects below the horizon if:
+	// + using Horizontal coords,
+	// + the ground is drawn,
+	// + and either of the following is true:
+	//   - focus is above the horizon
+	//   - field of view is larger than 50 degrees
+	if ( useAltAz && Options::showGround() && p->alt()->Degrees() < -2.0 
+				&& ( focus()->alt()->Degrees() > 0. || FOV > 50. ) ) return false;
+
 	if ( useAltAz ) {
 		dY = fabs( p->alt()->Degrees() - focus()->alt()->Degrees() );
 	} else {
@@ -1283,7 +1314,7 @@ void SkyMap::setMouseMoveCursor()
 }
 
 void SkyMap::addLink( void ) {
-	AddLinkDialog adialog( this );
+	AddLinkDialog adialog( this, clickedObject()->name() );
 	QString entry;
   QFile file;
 
@@ -1291,7 +1322,7 @@ void SkyMap::addLink( void ) {
 		if ( adialog.isImageLink() ) {
 			//Add link to object's ImageList, and descriptive text to its ImageTitle list
 			clickedObject()->ImageList.append( adialog.url() );
-			clickedObject()->ImageTitle.append( adialog.title() );
+			clickedObject()->ImageTitle.append( adialog.desc() );
 
 			//Also, update the user's custom image links database
 			//check for user's image-links database.  If it doesn't exist, create it.
@@ -1302,15 +1333,15 @@ void SkyMap::addLink( void ) {
 				KMessageBox::sorry( 0, message, i18n( "Could Not Open File" ) );
 				return;
 			} else {
-				entry = clickedObject()->name() + ":" + adialog.title() + ":" + adialog.url();
+				entry = clickedObject()->name() + ":" + adialog.desc() + ":" + adialog.url();
 				QTextStream stream( &file );
 				stream << entry << endl;
 				file.close();
-              emit linkAdded();
-      }
+				emit linkAdded();
+			}
 		} else {
 			clickedObject()->InfoList.append( adialog.url() );
-			clickedObject()->InfoTitle.append( adialog.title() );
+			clickedObject()->InfoTitle.append( adialog.desc() );
 
 			//check for user's image-links database.  If it doesn't exist, create it.
 			file.setName( locateLocal( "appdata", "info_url.dat" ) ); //determine filename in local user KDE directory tree.
@@ -1319,14 +1350,22 @@ void SkyMap::addLink( void ) {
 				QString message = i18n( "Custom information-links file could not be opened.\nLink cannot be recorded for future sessions." );						KMessageBox::sorry( 0, message, i18n( "Could not Open File" ) );
 				return;
 			} else {
-				entry = clickedObject()->name() + ":" + adialog.title() + ":" + adialog.url();
+				entry = clickedObject()->name() + ":" + adialog.desc() + ":" + adialog.url();
 				QTextStream stream( &file );
 				stream << entry << endl;
 				file.close();
-              emit linkAdded();
-      }
+				emit linkAdded();
+			}
 		}
 	}
 }
 
+void SkyMap::updateAngleRuler() {
+	if ( Options::useAltAz() ) PreviousClickedPoint.EquatorialToHorizontal( data->LST, data->geo()->lat() );
+	beginRulerPoint = getXY( previousClickedPoint(), Options::useAltAz(), Options::useRefraction() );
+
+//	endRulerPoint =  QPoint(e->x(), e->y());
+	endRulerPoint = mapFromGlobal( QCursor::pos() );
+}
+
 #include "skymap.moc"
