@@ -1,17 +1,15 @@
 /***************************************************************************
 
-    $Id: kva_header.cpp,v 1.24 2004/06/17 20:48:48 wheeler Exp $
-
                      header buttons part of kvoctrain
 
     -----------------------------------------------------------------------
 
     begin                : Thu Mar 11 20:50:53 MET 1999
-                                           
+
     copyright            : (C) 1999-2001 Ewald Arnold
                            (C) 2001 The KDE-EDU team
-                         
-    email                : kvoctrain@ewald-arnold.de                                    
+
+    email                : kvoctrain@ewald-arnold.de
 
     -----------------------------------------------------------------------
 
@@ -22,7 +20,7 @@
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   * 
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
@@ -42,6 +40,7 @@
 #include <klocale.h>
 #include <kdebug.h>
 #include <kstandarddirs.h>
+#include <kiconloader.h>
 
 void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
 {
@@ -50,8 +49,8 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
 
   if (header == KV_COL_LESS) {
     header_m = new QPopupMenu();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_num.xpm")), i18n(SORT_NUM), (header << 16) | IDH_SORT_COL_NUM);
+    header_m->insertItem(SmallIconSet("sort_incr"), i18n(SORT_ALPHA), (header << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(SmallIconSet("sort_num"), i18n(SORT_NUM), (header << 16) | IDH_SORT_COL_NUM);
 
     connect (header_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
     connect (header_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
@@ -96,25 +95,25 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
   header_m = new QPopupMenu();
 
   if (header != KV_COL_ORG - KV_EXTRA_COLS ) {
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), (header << 16) | IDH_START_QUERY);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), (header << 16) | IDH_START_MULTIPLE);
+    header_m->insertItem(SmallIconSet("run_query"), i18n("Create Random &Query"), (header << 16) | IDH_START_QUERY);
+    header_m->insertItem(SmallIconSet("run_multi"), i18n("Create &Multiple Choice"), (header << 16) | IDH_START_MULTIPLE);
     header_m->setItemEnabled((header << 16) | IDH_START_MULTIPLE, doc->numLangs() > 1);
     header_m->setItemEnabled((header << 16) | IDH_START_QUERY,  doc->numLangs() > 1);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("&Verbs"), (header << 16) | IDH_START_VERB);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Articles"), (header << 16) | IDH_START_ARTICLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Forms"), (header << 16) | IDH_START_ADJECTIVE);
+    header_m->insertItem(i18n("&Verbs"), (header << 16) | IDH_START_VERB);
+    header_m->insertItem(i18n("&Articles"), (header << 16) | IDH_START_ARTICLE);
+    header_m->insertItem(i18n("&Comparison Forms"), (header << 16) | IDH_START_ADJECTIVE);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("S&ynonyms"), (header << 16) | IDH_START_SYNONYM);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("A&ntonyms"), (header << 16) | IDH_START_ANTONYM);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-exmp.xpm")), i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
+    header_m->insertItem(i18n("S&ynonyms"), (header << 16) | IDH_START_SYNONYM);
+    header_m->insertItem(i18n("A&ntonyms"), (header << 16) | IDH_START_ANTONYM);
+    header_m->insertItem(i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
+    header_m->insertItem(i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
+    header_m->insertItem(SmallIconSet("sort_incr"), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(SmallIconSet("set_language"), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/reset.xpm")), i18n("Reset &Grades"), (header << 16) | IDH_RESET_GRADE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/delete-col.xpm")), i18n("&Remove Column"), (header << 16) | IDH_REMOVE );
+    header_m->insertItem(i18n("Reset &Grades"), (header << 16) | IDH_RESET_GRADE);
+    header_m->insertItem(SmallIconSet("delete_table_col"), i18n("&Remove Column"), (header << 16) | IDH_REMOVE );
   }
   else {
     QPopupMenu *query_m =  new QPopupMenu();
@@ -135,14 +134,14 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
       if((j = langset.indexShortId(doc->getIdent(i))) >= 0
          && !langset.PixMapFile(j).isEmpty()
          && !langset.longId(j).isEmpty() ) {
-        query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(names[i-1]),
+        query_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(names[i-1]),
             (i << (16+8)) |  IDH_START_QUERY);  // hack: IDs => header-ids + cmd
       }
       else {
-        query_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
+        query_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_QUERY);
       }
     }
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-query.xpm")), i18n("Create Random &Query"), query_m, (3 << 16) | IDH_NULL);
+    header_m->insertItem(SmallIconSet("run_query"), i18n("Create Random &Query"), query_m, (3 << 16) | IDH_NULL);
     connect (query_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
     connect (query_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
     for (int i = 1; i < (int) doc->numLangs(); i++) {
@@ -151,29 +150,29 @@ void kvoctrainApp::slotHeaderMenu(int header, int x, int y) /*FOLD00*/
       if((j = langset.indexShortId(doc->getIdent(i))) >= 0
          && !langset.PixMapFile(j).isEmpty()
          && !langset.longId(j).isEmpty() ) {
-        multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("from %1").arg(names[i-1]),
+        multiple_m->insertItem(QPixmap(langset.PixMapFile(j)), i18n("From %1").arg(names[i-1]),
             (i << (16+8)) |  IDH_START_MULTIPLE);  // hack: IDs => header-ids + cmd
       }
       else {
-        multiple_m->insertItem(i18n("from %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
+        multiple_m->insertItem(i18n("From %1").arg(doc->getIdent(i)), (i << (16+8)) |  IDH_START_MULTIPLE);
       }
     }
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-multi.xpm")), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
+    header_m->insertItem(SmallIconSet("run_multi"), i18n("Create &Multiple Choice"), multiple_m, (4 << 16) | IDH_NULL);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-verb.xpm")), i18n("Train &Verbs"), (header << 16) | IDH_START_VERB);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-art.xpm")), i18n("&Article Training"), (header << 16) | IDH_START_ARTICLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-adj.xpm")), i18n("&Comparison Training"), (header << 16) | IDH_START_ADJECTIVE);
+    header_m->insertItem(i18n("Train &Verbs"), (header << 16) | IDH_START_VERB);
+    header_m->insertItem(i18n("&Article Training"), (header << 16) | IDH_START_ARTICLE);
+    header_m->insertItem(i18n("&Comparison Training"), (header << 16) | IDH_START_ADJECTIVE);
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-syno.xpm")), i18n("&Synonyms"), (header << 16) | IDH_START_SYNONYM);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-anto.xpm")), i18n("&Antonyms"), (header << 16) | IDH_START_ANTONYM);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-exmp.xpm")), i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/run-para.xpm")), i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
+    header_m->insertItem(i18n("&Synonyms"), (header << 16) | IDH_START_SYNONYM);
+    header_m->insertItem(i18n("&Antonyms"), (header << 16) | IDH_START_ANTONYM);
+    header_m->insertItem(i18n("E&xamples"), (header << 16) | IDH_START_EXAMPLE);
+    header_m->insertItem(i18n("&Paraphrase"), (header << 16) | IDH_START_PARAPHRASE);
     connect (multiple_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
     connect (multiple_m, SIGNAL(highlighted(int)), this, SLOT(slotHeaderStatus(int)));
 
     header_m->insertSeparator();
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/sort_alpha.xpm")), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
-    header_m->insertItem(QPixmap(locate("data", "kvoctrain/flags.xpm")), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
+    header_m->insertItem(SmallIconSet("sort_incr"), i18n(SORT_ALPHA), (header+KV_EXTRA_COLS << 16) | IDH_SORT_COL_ALPHA);
+    header_m->insertItem(SmallIconSet("set_language"), i18n("Set &Language"), langs_m, (2 << 16) | IDH_NULL);
   }
 
   connect (header_m, SIGNAL(activated(int)), this, SLOT(slotHeaderCallBack(int)));
@@ -394,7 +393,7 @@ void kvoctrainApp::slotHeaderCallBack (int header_and_cmd) /*FOLD00*/
   int header2 = header_and_cmd >> (16+8);
   int cmd     = header_and_cmd & 0xFFFF;
 
-//cout << header1 << " " << header2 << " " << cmd << endl;
+  kdDebug() << header1 << " " << header2 << " " << cmd << endl;
 
   switch (cmd) {
     case IDH_SORT_COL_ALPHA:
@@ -446,11 +445,11 @@ void kvoctrainApp::slotHeaderCallBack (int header_and_cmd) /*FOLD00*/
                             "Do you really want to delete \"%1\"?");
       msg = format.arg(name);
 
-      int exit = KMessageBox::warningYesNo(this, msg,
-                    kapp->makeStdCaption(""));
-      if(exit==KMessageBox::Yes) {
+      int exit = KMessageBox::warningContinueCancel(this, msg,
+                    kapp->makeStdCaption(""),KStdGuiItem::del());
+      if(exit==KMessageBox::Continue) {
         doc->removeIdent(header1);
-        view->setView (doc, langset, gradecols);
+        view->setView (doc, langset);
         doc->setModified();
       }
     }
@@ -551,9 +550,9 @@ void kvoctrainApp::slotHeaderCallBack (int header_and_cmd) /*FOLD00*/
 
       msg = format.arg(name);
 
-      int exit = KMessageBox::warningYesNo(this, msg,
-                    kapp->makeStdCaption(""));
-      if(exit==KMessageBox::Yes) {
+      int exit = KMessageBox::warningContinueCancel(this, msg,
+                    kapp->makeStdCaption(""),i18n("Reset"));
+      if(exit==KMessageBox::Continue) {
         doc->resetEntry (header1, act_lesson);
         doc->setModified();
         view->getTable()->updateContents();
